@@ -6,7 +6,7 @@ use warnings;
 
 use parent qw(Data::Clean::Base);
 
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -36,7 +36,7 @@ Data::Clean::FromJSON - Clean data from JSON decoder
 
 =head1 VERSION
 
-version 0.16
+This document describes version 0.17 of Data::Clean::FromJSON (from Perl distribution Data-Clean-JSON), released on 2014-11-07.
 
 =head1 SYNOPSIS
 
@@ -84,7 +84,7 @@ LOG_CLEANSER_CODE
 
 [2013-10-15 ] This is also from Data::Clone::clone() when it encounters
 JSON::{PP,XS}::Boolean objects. You can use clean_in_place() instead of
-clone_and_clean(), or clone your data using other cloner like L<Storable>.
+clone_and_clean(), or clone your data using other cloner like L<Sereal>.
 
 =head1 HOMEPAGE
 
@@ -92,7 +92,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Clean
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Clean-JSON>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Clean-JSON>.
 
 =head1 BUGS
 
@@ -104,11 +104,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
